==> magpie-data-0.1.8-sources.jar: io/openraven/magpie/data/aws/cloudtrail/CloudTrail.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.cloudtrail;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.cloudtrail.model.TrailInfo;

@javax.persistence.Entity
@javax.persistence.Inheritance(strategy = javax.persistence.InheritanceType.TABLE_PER_CLASS)
@javax.persistence.Table(name = CloudTrail.TABLE_NAME)
public class CloudTrail extends AWSResource {

  protected static final String TABLE_NAME = "awscloudtrailtrail";
  public static final String RESOURCE_TYPE = "AWS::CloudTrail::Trail";

  public CloudTrail() {
    this.resourceType = RESOURCE_TYPE;

  }

  public CloudTrail(String account, String regionId, TrailInfo resource) {
    this.awsRegion = regionId;
    this.awsAccountId = account;
    this.arn = resource.trailARN();
    this.resourceName = resource.name();
    this.configuration = PayloadUtils.update(resource);
    this.resourceType = RESOURCE_TYPE;
  }
}

==> magpie-data-0.11.6-sources.jar: io/openraven/magpie/data/aws/cloudtrail/CloudTrail.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.cloudtrail;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.cloudtrail.model.TrailInfo;

@jakarta.persistence.Entity
@jakarta.persistence.Inheritance(strategy = jakarta.persistence.InheritanceType.TABLE_PER_CLASS)
@jakarta.persistence.Table(name = CloudTrail.TABLE_NAME)
public class CloudTrail extends AWSResource {

  protected static final String TABLE_NAME = "awscloudtrailtrail";
  public static final String RESOURCE_TYPE = "AWS::CloudTrail::Trail";

  public CloudTrail() {
    this.resourceType = RESOURCE_TYPE;

  }

  public CloudTrail(String account, String regionId, TrailInfo resource) {
    this.awsRegion = regionId;
    this.awsAccountId = account;
    this.arn = resource.trailARN();
    this.resourceName = resource.name();
    this.configuration = PayloadUtils.update(resource);
    this.resourceType = RESOURCE_TYPE;
  }
}
